Mysql-Tool

= = = = = = = = = =

Please use the latest version

1.0.1:

    Encapsulation for pymysql calls


1.0.4:

Solve coding problems
    
    Use from MySQL? Tool.mysql? Tool import my? MySQL


1.0.5:

Use from:
    
        from mysql_tool import my_mysqls


Install command: ` pip install Mysql-Tool`


[View address] (https://github.com/happyshi0402/mysql_tool)!